@@ -5,6 +5,7 @@ use crate::file_context::FileContext;
 use crate::parser::parse_imported_scss_file;
 use crate::sass::{
     self, get_global_module, Expose, FormalArgs, Function, Item, Mixin, Name,
+    UseAs,
 };
 use crate::selectors::Selectors;
 use crate::value::ValueRange;
@@ -165,15 +166,22 @@ fn handle_item(
                             pos.clone(),
                         )?;
                         let mut thead = CssHead::new(format);
+                        let module = ScopeRef::sub(scope.clone());
                         handle_body(
                             &items,
                             &mut thead,
                             rule.as_deref_mut(),
                             buf,
-                            scope.clone(),
+                            module.clone(),
                             &sub_context,
                         )?;
                         head.merge_imports(thead);
+                        scope.do_use(
+                            module,
+                            "",
+                            &UseAs::Star,
+                            &Expose::All,
+                        )?;
                         continue 'name;
                     }
                 }
@@ -302,7 +310,7 @@ fn handle_item(
                     .args
                     .eval(
                         ScopeRef::sub_selectors(mixin.scope, sel),
-                        &args.evaluate(scope.clone(), true)?,
+                        args.evaluate(scope.clone())?,
                     )
                     .map_err(|e| match e {
                         sass::ArgsError::Eval(e) => e,
@@ -313,7 +321,7 @@ fn handle_item(
                     Mixin {
                         args: FormalArgs::none(),
                         scope,
-                        body: body.clone(),
+                        body: body.clone().unwrap_or_else(Mixin::no_body),
                     },
                 );
                 handle_body(
@@ -332,24 +340,18 @@ fn handle_item(
             }
         }
         Item::Content => {
-            if let Some(rule) = rule {
-                if let Some(content) =
-                    scope.get_mixin(&Name::from_static("%%BODY%%"))
-                {
-                    let sel = scope.get_selectors().clone();
-                    handle_body(
-                        &content.body,
-                        head,
-                        Some(rule),
-                        buf,
-                        ScopeRef::sub_selectors(content.scope, sel),
-                        file_context,
-                    )?;
-                }
-            } else {
-                return Err(Error::S(
-                    "@content not allowed in global context".into(),
-                ));
+            if let Some(content) =
+                scope.get_mixin(&Name::from_static("%%BODY%%"))
+            {
+                let sel = scope.get_selectors().clone();
+                handle_body(
+                    &content.body,
+                    head,
+                    rule,
+                    buf,
+                    ScopeRef::sub_selectors(content.scope, sel),
+                    file_context,
+                )?;
             }
         }
 
